<!-- CHUNK ID: chunk_9221A870  CHUNK TYPE: paragraph START_LINE:1 -->
[**Advanced**](./introduction.md) > **Documentation of Translation Services** _(current)_

<!-- CHUNK ID: h_rule_0ff56125  CHUNK TYPE: h_rule START_LINE:3 -->
---

<!-- CHUNK ID: chunk_7775DA81  CHUNK TYPE: header START_LINE:5 -->
### Viewing Available Translate Services via Command Line

<!-- CHUNK ID: chunk_4919DFD2  CHUNK TYPE: paragraph START_LINE:7 -->
You can confirm the available translate services and their usage by printing the help message in the command line.

<!-- CHUNK ID: chunk_756565E6  CHUNK TYPE: code_block START_LINE:9 -->
```bash
pdf2zh_next -h
```

<!-- CHUNK ID: chunk_7935E690  CHUNK TYPE: paragraph START_LINE:13 -->
At the end of the help message, you can view detailed information about the different translation services.
